use std::fmt::Display;

#[derive(Debug)]
pub enum BinError {
    UnpackError(String),
}

impl Display for BinError {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            BinError::UnpackError(e) => write!(f, "Unpack error: {}", e),
        }
    }
}

#[derive(Debug)]
pub enum BuildError {
    InvalidManifest,
}

impl Display for BuildError {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            _ => write!(f, "Build error"),
        }
    }
}

#[derive(Debug)]
pub enum InstallError {
    BuildError(BuildError),
    BinError(BinError),
    InvalidManifest,
    Generic,
}

impl ToString for InstallError {
    fn to_string(&self) -> String {
        match self {
            InstallError::BuildError(e) => format!("{}", e),
            InstallError::BinError(e) => format!("{}", e),
            InstallError::InvalidManifest => "Invalid manifest".to_string(),
            InstallError::Generic => "Install error".to_string(),
        }
    }
}
